@@ -10,3 +10,6 @@ writer_name = "latex"
 # Extra setting we need
 settings_overrides['syntax_highlight'] = 'none'
 settings_overrides['stylesheet'] = 'docutils'
+
+settings_overrides['legacy_column_widths'] = True
+settings_overrides['use_latex_citations'] = False
