@@ -1,4 +1,6 @@
-exec(open('functional/tests/_standalone_rst_defaults.py').read())
+with open('functional/tests/_standalone_rst_defaults.py',
+          encoding='utf-8') as _f:
+    exec(_f.read())
 
 # Source and destination file names.
 test_source = "standalone_rst_html4css1.txt"
@@ -8,7 +10,6 @@ test_destination = "standalone_rst_html4css1.html"
 writer_name = "html4css1"
 
 # Settings:
-# local copy of default stylesheet:
+# local copy of stylesheets:
 # (Test runs in ``docutils/test/``, we need relative path from there.)
-settings_overrides['stylesheet_path'] = ( 
-    'functional/input/data/html4css1.css')
+settings_overrides['stylesheet_dirs'] = ('.', 'functional/input/data')
