@@ -1,4 +1,5 @@
-with open('functional/tests/_standalone_rst_defaults.py') as _f:
+with open('functional/tests/_standalone_rst_defaults.py',
+          encoding='utf-8') as _f:
     exec(_f.read())
 
 # Source and destination file names.
@@ -15,3 +16,5 @@ settings_overrides['smart_quotes'] = True
 settings_overrides['stylesheet'] = 'docutils'
 # Test the ToC generation by Docutils:
 settings_overrides['use_latex_toc'] = False
+settings_overrides['legacy_column_widths'] = True
+settings_overrides['use_latex_citations'] = False
