@@ -1,23 +1,24 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_compound.py 8481 2020-01-31 08:17:24Z milde $
+# $Id: test_compound.py 9037 2022-03-05 23:31:10Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for the 'compound' directive from body.py.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
+    import __init__  # noqa: F401
 from test_parsers import DocutilsTestSupport
 
+
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['compound'] = [
