@@ -1,16 +1,15 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_meta.py 8767 2021-06-17 14:33:28Z milde $
+# $Id: test_meta.py 9037 2022-03-05 23:31:10Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for html meta directives.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
+    import __init__  # noqa: F401
 from test_parsers import DocutilsTestSupport
 
 
@@ -19,6 +18,7 @@ def suite():
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['meta'] = [
