@@ -1,6 +1,6 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_title.py 5174 2007-05-31 00:01:52Z wiemann $
+# $Id: test_title.py 9037 2022-03-05 23:31:10Z milde $
 # Author: Lea Wiemann <LeWiemann@gmail.com>
 # Copyright: This module has been placed in the public domain.
 
@@ -8,13 +8,17 @@
 Tests for the 'title' directive.
 """
 
-from __init__ import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__  # noqa: F401
+from test_parsers import DocutilsTestSupport
+
 
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['title'] = [
