@@ -1,16 +1,17 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 3915 $
-# Date: $Date: 2005-10-02 03:06:42 +0200 (Sun, 02 Oct 2005) $
+# $Id: test_unicode.py 9037 2022-03-05 23:31:10Z milde $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for misc.py "unicode" directive.
 """
 
-from __init__ import DocutilsTestSupport
+
+if __name__ == '__main__':
+    import __init__  # noqa: F401
+from test_parsers import DocutilsTestSupport
 
 
 def suite():
@@ -18,6 +19,14 @@ def suite():
     s.generateTests(totest)
     return s
 
+
+unichr_exception = DocutilsTestSupport.exception_data(
+    chr, int("111111111111111111", 16))[0]
+if isinstance(unichr_exception, OverflowError):
+    unichr_exception_string = 'code too large (%s)' % unichr_exception
+else:
+    unichr_exception_string = str(unichr_exception)
+
 totest = {}
 
 totest['unicode'] = [
@@ -31,7 +40,7 @@ space (|nbsp|), a backwards-not-equals (|bne|), and a captial omega (|Omega|).
 .. |bne| unicode:: U0003D U020E5
 .. |Omega| unicode:: U+003A9
 """,
-u"""\
+"""\
 <document source="test data">
     <paragraph>
         Insert an em-dash (
@@ -92,9 +101,9 @@ Bad input:
             Substitution definition "empty too" empty or invalid.
         <literal_block xml:space="preserve">
             .. |empty too| unicode:: .. comment doesn't count as content
-    <substitution_definition names="not\ hex">
+    <substitution_definition names="not\\ hex">
         0xHEX
-    <substitution_definition names="not\ all\ hex">
+    <substitution_definition names="not\\ all\\ hex">
         UABCX
     <system_message level="3" line="8" source="test data" type="ERROR">
         <paragraph>
@@ -111,21 +120,21 @@ Copyright |copy| 2003, |BogusMegaCorp (TM)|.
 .. |BogusMegaCorp (TM)| unicode:: BogusMegaCorp U+2122
    .. with trademark sign
 """,
-u"""\
+"""\
 <document source="test data">
     <paragraph>
         Testing comments and extra text.
     <paragraph>
-        Copyright 
+        Copyright \n\
         <substitution_reference refname="copy">
             copy
-         2003, 
+         2003, \n\
         <substitution_reference refname="BogusMegaCorp (TM)">
             BogusMegaCorp (TM)
         .
     <substitution_definition names="copy">
         \u00A9
-    <substitution_definition names="BogusMegaCorp\ (TM)">
+    <substitution_definition names="BogusMegaCorp\\ (TM)">
         BogusMegaCorp
         \u2122
 """],
@@ -157,13 +166,8 @@ u"""\
             Substitution definition "too big for unicode" empty or invalid.
         <literal_block xml:space="preserve">
             .. |too big for unicode| unicode:: 0x11111111
-""" % ([DocutilsTestSupport.exception_data(
-            'unichr(int("111111111111111111", 16))')[0],
-        'code too large (%s)' % DocutilsTestSupport.exception_data(
-    'unichr(int("111111111111111111", 16))')[0]]
-       [isinstance(DocutilsTestSupport.exception_data(
-    'unichr(int("111111111111111111", 16))')[0], OverflowError)],
-       DocutilsTestSupport.exception_data('unichr(int("11111111", 16))')[2])]
+""" % (unichr_exception_string,
+       DocutilsTestSupport.exception_data(chr, int("11111111", 16))[2])]
 ]
 
 
