@@ -1,43 +1,34 @@
-#! /usr/bin/env python
-# -*- coding: utf-8 -*-
-
-# $Id: test_east_asian_text.py 8771 2021-06-18 18:55:08Z milde $
+#! /usr/bin/env python3
+# $Id: test_east_asian_text.py 9037 2022-03-05 23:31:10Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for East Asian text with double-width characters.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
+    import __init__  # noqa: F401
 from test_parsers import DocutilsTestSupport
 
-import unicodedata
-
-try:
-    east_asian_width = unicodedata.east_asian_width
-except AttributeError:
-    east_asian_width = None
-
 
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['double-width'] = [
-[u"""\
+["""\
 タイトル1
 =========
 
 タイトル2
 ========
 """,
-u"""\
+"""\
 <document source="test data">
     <section ids="section-1" names="タイトル1">
         <title>
@@ -52,7 +43,7 @@ u"""\
                 タイトル2
                 ========
 """],
-[u"""
+["""
 +-----------------------+
 | * ヒョウ:ダイ1ギョウ  |
 | * ダイ2ギョウ         |
@@ -61,7 +52,7 @@ u"""\
 | * ダイ2ギョウ         |
 +-----------------------+
 """,
-u"""\
+"""\
 <document source="test data">
     <table>
         <tgroup cols="1">
@@ -82,7 +73,7 @@ u"""\
                             * ダイ1ギョウ
                             * ダイ2ギョウ
 """],
-[u"""\
+["""\
 Complex spanning pattern (no edge knows all rows/cols):
 
 +--------+---------------------+
@@ -93,7 +84,7 @@ Complex spanning pattern (no edge knows all rows/cols):
 | 南西・南セル          | セル |
 +-----------------------+------+
 """,
-u"""\
+"""\
 <document source="test data">
     <paragraph>
         Complex spanning pattern (no edge knows all rows/cols):
@@ -125,7 +116,7 @@ u"""\
                         <paragraph>
                             南西・南セル
 """],
-[u"""\
+["""\
 =========  =========
 ダイ1ラン  ダイ2ラン
 =========  =========
@@ -134,7 +125,7 @@ u"""\
 ダイ1ラン ダイ2ラン
 ========  =========
 """,
-u"""\
+"""\
 <document source="test data">
     <table>
         <tgroup cols="2">
@@ -157,7 +148,7 @@ u"""\
             ダイ1ラン ダイ2ラン
             ========  =========
 """],
-[u"""\
+["""\
 Some ambiguous-width characters:
 
 = ===================================
@@ -311,9 +302,9 @@ b"""\
 """.decode('raw_unicode_escape')],
 ]
 '''
-[u"""\
+["""\
 """,
-u"""\
+"""\
 """],
 '''
 
