@@ -1,25 +1,32 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 1.9 $
-# Date: $Date: 2002/10/24 01:00:37 $
+# $Id: test_tables.py 9037 2022-03-05 23:31:10Z milde $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for states.py.
 """
 
-from __init__ import DocutilsTestSupport
+import os
+
+if __name__ == '__main__':
+    import __init__  # noqa: F401
+from test_parsers import DocutilsTestSupport
+
 
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
     s.generateTests(totest)
     return s
 
+
+mydir = 'test_parsers/test_rst/'
+include2 = os.path.join(mydir, 'test_directives/include2.txt')
+
 totest = {}
 
-totest['full_tables'] = [
+totest['grid_tables'] = [
 ["""\
 +-------------------------------------+
 | A table with one cell and one line. |
@@ -557,6 +564,74 @@ No blank line after table.
                             with empty cells
                     <entry>
 """],
+[("""\
++------------------------------------------------------------------------------+
+| .. include::                                                                 |
+%s
++------------------------------------------------------------------------------+
+| (The first cell of this table may expand                                     |
+| to accommodate long filesystem paths.)                                       |
++------------------------------------------------------------------------------+
+""") % ('\n'.join('|    %-70s    |' % include2[part * 70 : (part + 1) * 70]  # noqa: E203
+                  for part in range(len(include2) // 70 + 1))),
+"""\
+<document source="test data">
+    <table>
+        <tgroup cols="1">
+            <colspec colwidth="78">
+            <tbody>
+                <row>
+                    <entry>
+                        <paragraph>
+                            Here are some paragraphs
+                            that can appear at any level.
+                        <paragraph>
+                            This file (include2.txt) is used by
+                            <literal>
+                                test_include.py
+                            .
+                <row>
+                    <entry>
+                        <paragraph>
+                            (The first cell of this table may expand
+                            to accommodate long filesystem paths.)
+"""],
+[("""\
+Something before.
+
++------------------------------------------------------------------------------+
+| .. include::                                                                 |
+%s
++------------------------------------------------------------------------------+
+
+Something afterwards.
+
+And more.
+""") % ('\n'.join('|    %-70s    |' % include2[part * 70 : (part + 1) * 70]  # noqa: E203
+                  for part in range(len(include2) // 70 + 1))),
+"""\
+<document source="test data">
+    <paragraph>
+        Something before.
+    <table>
+        <tgroup cols="1">
+            <colspec colwidth="78">
+            <tbody>
+                <row>
+                    <entry>
+                        <paragraph>
+                            Here are some paragraphs
+                            that can appear at any level.
+                        <paragraph>
+                            This file (include2.txt) is used by
+                            <literal>
+                                test_include.py
+                            .
+    <paragraph>
+        Something afterwards.
+    <paragraph>
+        And more.
+"""],
 ]
 
 totest['simple_tables'] = [
@@ -719,6 +794,56 @@ A table with three  columns.
 """],
 ["""\
 ==============  ======
+A simple table  this text extends to the right
+cell 3          as does this text
+==============  ======
+""",
+"""\
+<document source="test data">
+    <table>
+        <tgroup cols="2">
+            <colspec colwidth="14">
+            <colspec colwidth="30">
+            <tbody>
+                <row>
+                    <entry>
+                        <paragraph>
+                            A simple table
+                    <entry>
+                        <paragraph>
+                            this text extends to the right
+                <row>
+                    <entry>
+                        <paragraph>
+                            cell 3
+                    <entry>
+                        <paragraph>
+                            as does this text
+"""],
+["""\
+==============  ======
+A simple table  this text extends to the right
+                continuation of cell 2
+==============  ======
+""",
+"""\
+<document source="test data">
+    <table>
+        <tgroup cols="2">
+            <colspec colwidth="14">
+            <colspec colwidth="30">
+            <tbody>
+                <row>
+                    <entry>
+                        <paragraph>
+                            A simple table
+                    <entry>
+                        <paragraph>
+                            this text extends to the right
+                            continuation of cell 2
+"""],
+["""\
+==============  ======
 A simple table  with
 no bottom       border
 """,
@@ -826,10 +951,10 @@ cell 3          cell 4
 """,
 """\
 <document source="test data">
-    <system_message level="3" line="1" source="test data" type="ERROR">
+    <system_message level="3" line="4" source="test data" type="ERROR">
         <paragraph>
             Malformed table.
-            Column span alignment problem at line offset 2.
+            Column span alignment problem in table line 4.
         <literal_block xml:space="preserve">
             ==============  ======
             A bad table     cell 2
@@ -844,10 +969,10 @@ cell 3       cell 4
 """,
 """\
 <document source="test data">
-    <system_message level="3" line="1" source="test data" type="ERROR">
+    <system_message level="3" line="2" source="test data" type="ERROR">
         <paragraph>
             Malformed table.
-            Text in column margin at line offset 1.
+            Text in column margin in table line 2.
         <literal_block xml:space="preserve">
             ========  =========
             A bad table  cell 2
@@ -1088,10 +1213,10 @@ A table with  many row separators.
 """,
 """\
 <document source="test data">
-    <system_message level="3" line="1" source="test data" type="ERROR">
+    <system_message level="3" line="4" source="test data" type="ERROR">
         <paragraph>
             Malformed table.
-            Text in column margin at line offset 3.
+            Text in column margin in table line 4.
         <literal_block xml:space="preserve">
             ==  ===========  ===========
             1   Span columns 2 & 3
@@ -1100,10 +1225,10 @@ A table with  many row separators.
                 ------------------------
             3
             ==  ===========  ===========
-    <system_message level="3" line="9" source="test data" type="ERROR">
+    <system_message level="3" line="13" source="test data" type="ERROR">
         <paragraph>
             Malformed table.
-            Column span incomplete at line offset 4.
+            Column span incomplete in table line 5.
         <literal_block xml:space="preserve">
             ==  ===========  ===========
             1 Span cols 1&2  but not 3
@@ -1123,14 +1248,14 @@ A table with  many row separators.
                         <paragraph>
                             1
                     <entry>
-                        <system_message level="4" line="20" source="test data" type="SEVERE">
+                        <system_message level="4" line="19" source="test data" type="SEVERE">
                             <paragraph>
                                 Unexpected section title.
                             <literal_block xml:space="preserve">
                                 Not a span
                                 -----------
                     <entry>
-                        <system_message level="4" line="20" source="test data" type="SEVERE">
+                        <system_message level="4" line="19" source="test data" type="SEVERE">
                             <paragraph>
                                 Unexpected section title.
                             <literal_block xml:space="preserve">
@@ -1143,6 +1268,44 @@ A table with  many row separators.
                     <entry>
                     <entry>
 """],
+["""\
+=========  =====================================================================
+Inclusion  .. include::
+%s
+Note       The first row of this table may expand
+           to accommodate long filesystem paths.
+=========  =====================================================================
+""" % ('\n'.join('              %-65s' % include2[part * 65 : (part + 1) * 65]  # noqa: E203
+                 for part in range(len(include2) // 65 + 1))),
+"""\
+<document source="test data">
+    <table>
+        <tgroup cols="2">
+            <colspec colwidth="9">
+            <colspec colwidth="69">
+            <tbody>
+                <row>
+                    <entry>
+                        <paragraph>
+                            Inclusion
+                    <entry>
+                        <paragraph>
+                            Here are some paragraphs
+                            that can appear at any level.
+                        <paragraph>
+                            This file (include2.txt) is used by
+                            <literal>
+                                test_include.py
+                            .
+                <row>
+                    <entry>
+                        <paragraph>
+                            Note
+                    <entry>
+                        <paragraph>
+                            The first row of this table may expand
+                            to accommodate long filesystem paths.
+"""],
 ]
 
 
