@@ -1,17 +1,16 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_transitions.py 8481 2020-01-31 08:17:24Z milde $
+# $Id: test_transitions.py 9037 2022-03-05 23:31:10Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Test module for misc.Transitions transform.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
-from test_transforms import DocutilsTestSupport # before importing docutils!
+    import __init__  # noqa: F401
+from test_transforms import DocutilsTestSupport  # before importing docutils!
 from docutils.transforms.misc import Transitions
 from docutils.parsers.rst import Parser
 
@@ -175,7 +174,7 @@ A paragraph and two transitions.
 ----------
 
 ----------
-""", # the same:
+""",
 """\
 <document source="test data">
     <paragraph>
