@@ -1,6 +1,6 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 
-# $Id: test_html5_polyglot_parts.py 8853 2021-10-13 15:42:30Z milde $
+# $Id: test_html5_polyglot_parts.py 9081 2022-06-19 20:23:12Z milde $
 # Author: reggie dugard <reggie@users.sourceforge.net>
 # Copyright: This module has been placed in the public domain.
 
@@ -11,14 +11,12 @@ Note: the 'body' and 'whole' entries have been removed from the parts
 dictionaries (redundant), along with 'meta' and 'stylesheet' entries with
 standard values, and any entries with empty values.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
-from test_transforms import DocutilsTestSupport  # before importing docutils!
+    import __init__  # noqa: F401
 from DocutilsTestSupport import (HtmlWriterPublishPartsTestCase,
                                  HtmlPublishPartsTestSuite)
-from docutils import core, __version__
+from docutils import __version__
 
 
 class Html5WriterPublishPartsTestCase(HtmlWriterPublishPartsTestCase):
@@ -28,11 +26,11 @@ class Html5WriterPublishPartsTestCase(HtmlWriterPublishPartsTestCase):
     settings_default_overrides = HtmlWriterPublishPartsTestCase.settings_default_overrides.copy()
     settings_default_overrides['section_self_link'] = True
 
-    standard_content_type_template = ('<meta charset="%s"/>\n')
-    standard_generator_template = ('<meta name="generator"'
-        ' content="Docutils %s: http://docutils.sourceforge.net/" />\n')
-    standard_viewport_template = ('<meta name="viewport"'
-        ' content="width=device-width, initial-scale=1" />\n')
+    standard_content_type_template = '<meta charset="%s" />\n'
+    standard_generator_template = '<meta name="generator"' \
+        ' content="Docutils %s: https://docutils.sourceforge.io/" />\n'
+    standard_viewport_template = '<meta name="viewport"' \
+        ' content="width=device-width, initial-scale=1" />\n'
 
     standard_html_meta_value = (standard_content_type_template
                                 + standard_viewport_template
@@ -40,6 +38,7 @@ class Html5WriterPublishPartsTestCase(HtmlWriterPublishPartsTestCase):
     standard_meta_value = standard_html_meta_value % 'utf-8'
     standard_html_prolog = '<!DOCTYPE html>\n'
 
+
 class Html5PublishPartsTestSuite(HtmlPublishPartsTestSuite):
 
     testcase_class = Html5WriterPublishPartsTestCase
@@ -206,7 +205,7 @@ Some stuff
 """]
 ])
 
-totest['No title promotion'] = ({'doctitle_xform' : 0,
+totest['No title promotion'] = ({'doctitle_xform': 0,
                                  'stylesheet_path': '',
                                  'embed_stylesheet': 0}, [
 ["""\
@@ -600,7 +599,6 @@ because the unit &quot;uf&quot; is invalid.</p>
 </main>\\n''',
  'html_head': '''...<title>&lt;string&gt;</title>\\n'''}
 """],
-])
 ["""\
 .. figure:: dummy.png
 
@@ -621,6 +619,7 @@ No caption nor legend.
 </main>\\n''',
  'html_head': '''...<title>&lt;string&gt;</title>\\n'''}
 """],
+])
 
 
 totest['lazy loading'] = ({'image_loading': 'lazy',
@@ -657,6 +656,75 @@ totest['lazy loading'] = ({'image_loading': 'lazy',
 """],
 ])
 
+
+totest['no backlinks'] = ({'footnote_backlinks': False,
+                           'stylesheet_path': '',
+                           'embed_stylesheet': 0}, [
+
+["""\
+Two footnotes [#f1]_ [#f2]_ and two citations [once]_ [twice]_.
+
+The latter are referenced a second time [#f2]_ [twice]_.
+
+.. [#f1] referenced once
+.. [#f2] referenced twice
+.. [once] citation referenced once
+.. [twice] citation referenced twice
+""",
+"""\
+{'fragment': '''\
+<p>Two footnotes <a class="footnote-reference brackets" href="#f1" id="footnote-reference-1" role="doc-noteref"><span class="fn-bracket">[</span>1<span class="fn-bracket">]</span></a> <a class="footnote-reference brackets" href="#f2" id="footnote-reference-2" role="doc-noteref"><span class="fn-bracket">[</span>2<span class="fn-bracket">]</span></a> and two citations <a class="citation-reference" href="#once" id="citation-reference-1" role="doc-biblioref">[once]</a> <a class="citation-reference" href="#twice" id="citation-reference-2" role="doc-biblioref">[twice]</a>.</p>
+<p>The latter are referenced a second time <a class="footnote-reference brackets" href="#f2" id="footnote-reference-3" role="doc-noteref"><span class="fn-bracket">[</span>2<span class="fn-bracket">]</span></a> <a class="citation-reference" href="#twice" id="citation-reference-3" role="doc-biblioref">[twice]</a>.</p>
+<aside class="footnote-list brackets">
+<aside class="footnote brackets" id="f1" role="note">
+<span class="label"><span class="fn-bracket">[</span>1<span class="fn-bracket">]</span></span>
+<p>referenced once</p>
+</aside>
+<aside class="footnote brackets" id="f2" role="note">
+<span class="label"><span class="fn-bracket">[</span>2<span class="fn-bracket">]</span></span>
+<p>referenced twice</p>
+</aside>
+</aside>
+<div role="list" class="citation-list">
+<div class="citation" id="once" role="doc-biblioentry">
+<span class="label"><span class="fn-bracket">[</span>once<span class="fn-bracket">]</span></span>
+<p>citation referenced once</p>
+</div>
+<div class="citation" id="twice" role="doc-biblioentry">
+<span class="label"><span class="fn-bracket">[</span>twice<span class="fn-bracket">]</span></span>
+<p>citation referenced twice</p>
+</div>
+</div>\\n''',
+ 'html_body': '''\
+<main>
+<p>Two footnotes <a class="footnote-reference brackets" href="#f1" id="footnote-reference-1" role="doc-noteref"><span class="fn-bracket">[</span>1<span class="fn-bracket">]</span></a> <a class="footnote-reference brackets" href="#f2" id="footnote-reference-2" role="doc-noteref"><span class="fn-bracket">[</span>2<span class="fn-bracket">]</span></a> and two citations <a class="citation-reference" href="#once" id="citation-reference-1" role="doc-biblioref">[once]</a> <a class="citation-reference" href="#twice" id="citation-reference-2" role="doc-biblioref">[twice]</a>.</p>
+<p>The latter are referenced a second time <a class="footnote-reference brackets" href="#f2" id="footnote-reference-3" role="doc-noteref"><span class="fn-bracket">[</span>2<span class="fn-bracket">]</span></a> <a class="citation-reference" href="#twice" id="citation-reference-3" role="doc-biblioref">[twice]</a>.</p>
+<aside class="footnote-list brackets">
+<aside class="footnote brackets" id="f1" role="note">
+<span class="label"><span class="fn-bracket">[</span>1<span class="fn-bracket">]</span></span>
+<p>referenced once</p>
+</aside>
+<aside class="footnote brackets" id="f2" role="note">
+<span class="label"><span class="fn-bracket">[</span>2<span class="fn-bracket">]</span></span>
+<p>referenced twice</p>
+</aside>
+</aside>
+<div role="list" class="citation-list">
+<div class="citation" id="once" role="doc-biblioentry">
+<span class="label"><span class="fn-bracket">[</span>once<span class="fn-bracket">]</span></span>
+<p>citation referenced once</p>
+</div>
+<div class="citation" id="twice" role="doc-biblioentry">
+<span class="label"><span class="fn-bracket">[</span>twice<span class="fn-bracket">]</span></span>
+<p>citation referenced twice</p>
+</div>
+</div>
+</main>\\n''',
+ 'html_head': '''...<title>&lt;string&gt;</title>\\n'''}
+"""],
+])
+
+
 if __name__ == '__main__':
     import unittest
     unittest.main(defaultTest='suite')
