@@ -1,16 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
-# $Id: test_null.py 8481 2020-01-31 08:17:24Z milde $
+# $Id: test_null.py 9037 2022-03-05 23:31:10Z milde $
 # Author: Lea Wiemann <LeWiemann@gmail.com>
 # Copyright: This module has been placed in the public domain.
 
 """
 Test for Null writer.
 """
-from __future__ import absolute_import
 
 if __name__ == '__main__':
-    import __init__
+    import __init__  # noqa: F401
 from test_writers import DocutilsTestSupport
 
 
@@ -19,6 +18,7 @@ def suite():
     s.generateTests(totest)
     return s
 
+
 totest = {}
 
 totest['basic'] = [
